@@ -2,9 +2,7 @@ package Bread::Board;
 BEGIN {
   $Bread::Board::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Bread::Board::VERSION = '0.30';
-}
+$Bread::Board::VERSION = '0.31';
 use strict;
 use warnings;
 use Carp qw(confess);
@@ -246,13 +244,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bread::Board - A solderless way to wire up your application components
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -265,8 +265,7 @@ version 0.30
       service 'logger' => (
           class        => 'FileLogger',
           lifecycle    => 'Singleton',
-          dependencies => [
-              depends_on('log_file_name'),
+          dependencies => [ 'log_file_name' ],
           ]
       );
 
@@ -285,15 +284,15 @@ version 0.30
                       $s->param('password'),
                   ) || die "Could not connect";
               },
-              dependencies => wire_names(qw[dsn username password])
+              dependencies => [ 'dsn', 'username', 'password' ]
           );
       };
 
       service 'application' => (
           class        => 'MyApplication',
           dependencies => {
-              logger => depends_on('logger'),
-              dbh    => depends_on('Database/dbh'),
+              logger => 'logger',
+              dbh    => 'Database/dbh',
           }
       );
 
@@ -459,6 +458,65 @@ of these is present, constructor injection will be used with
 L<Bread::Board::ConstructorInjection> (and you must provide the C<class>
 option).
 
+The C<dependencies> parameter takes a hashref of dependency names mapped to
+L<Bread::Board::Dependency> objects, but there are several coercions and sugar
+functions available to make specifying dependencies as easy as possible. The
+simplest case is when the names of the services you're depending on are the
+same as the names that the service you're defining will be accessing them with.
+In this case, you can just specify an arrayref of service names:
+
+  service foo => (
+      dependencies => [ 'bar', 'baz' ],
+      # ...
+  );
+
+If you need to use a different name, you can specify the dependencies as a
+hashref instead:
+
+  service foo => (
+      dependencies => {
+          dbh => 'foo_dbh',
+      },
+      # ...
+  );
+
+You can also specify parameters when depending on a parameterized service:
+
+  service foo => (
+      dependencies => [
+          { bar => { bar_param => 1 } },
+          'baz',
+      ],
+      # ...
+  );
+
+Finally, services themselves can also be specified as dependencies, in which
+case they will just be resolved directly:
+
+  service foo => (
+      dependencies => {
+          dsn => Bread::Board::Literal->new(
+              name  => 'dsn',
+              value => 'dbi:mysql:mydb',
+          ),
+      },
+      # ...
+  );
+
+As a special case, an arrayref of dependencies will be interpreted as a service
+which returns an arrayref containing the resolved values of those dependencies:
+
+  service foo => (
+      dependencies => {
+          # items will resolve to [ $bar_service->get, $baz_service->get ]
+          items => [
+              'bar',
+              Bread::Board::Literal->new(name => 'baz', value => 'BAZ'),
+          ],
+      },
+      # ...
+  );
+
 If the C<$name> starts with a C<'+'>, the service definition will instead
 extend an existing service with the given C<$name> (without the C<'+'>). This
 works similarly to the C<has '+foo'> syntax in Moose. It is most useful when
@@ -477,14 +535,8 @@ named C<$service_path> and returns it.
 =item I<wire_names (@service_names)>
 
 This function is just a shortcut for passing a hash reference of dependencies
-into the service.
-
-  service foo => (
-      class => "Pity::TheFoo',
-      dependencies => wire_names(qw( foo bar baz )),
-  );
-
-The above is identical to:
+into the service. It is not typically needed, since Bread::Board can usually
+understand what you mean - these declarations are all equivalent:
 
   service foo => (
       class => 'Pity::TheFoo',
@@ -495,6 +547,25 @@ The above is identical to:
       },
   );
 
+  service foo => (
+      class => 'Pity::TheFoo',
+      dependencies => wire_names(qw( foo bar baz )),
+  );
+
+  service foo => (
+      class => 'Pity::TheFoo',
+      dependencies => {
+          foo => 'foo',
+          bar => 'bar',
+          baz => 'baz',
+      },
+  );
+
+  service foo => (
+      class => 'Pity::TheFoo',
+      dependencies => [ qw(foo bar baz ) ],
+  );
+
 =item I<typemap ($type, $service | $service_path)>
 
 This creates a type mapping for the named type. Typically, it is paired with
